@@ -1,7 +1,7 @@
 /* giza - a scientific plotting library built on cairo
  *
  * Copyright (c) 2010      James Wetter and Daniel Price
- * Copyright (c) 2010-2012 Daniel Price
+ * Copyright (c) 2010-2022 Daniel Price
  *
  * This library is free software; and you are welcome to redistribute
  * it under the terms of the GNU General Public License
@@ -23,3 +23,5 @@
  */
 
 void _giza_stroke (void);
+void _giza_tick_intervals (double xmin, double xmax, double xinterval,
+				               int *i1, int *i2);
